<p align="center">
    <a href="https://docs.clast.dev/skidtools">
    <img src="https://raw.githubusercontent.com/Abd0s/skidtools/master/brand_assets/cover_4.png"/>
</p>

<p align="center">
  <a href="https://travis-ci.org/Abd0s/skidtools"><img
    src="https://travis-ci.org/Abd0s/skidtools.svg?branch=master"
    alt="Travis CI"
  /></a>
  <a href="http://hits.dwyl.com/Abd0s/skidtools"><img
    src="http://hits.dwyl.com/Abd0s/skidtools.svg" 
    alt="Hits"
  /></a>
   <a href="https://www.gnu.org/licenses/gpl-3.0"><img 
    src="https://img.shields.io/badge/License-GPLv3-blue.svg" 
    alt="License"
  /></a>
  <a href="https://pypi.org/project/Skidtools/"><img 
    alt="PyPI" 
    src="https://img.shields.io/pypi/v/skidtools"
  /></a>
</p>

<p align="center">
  A collection of utilities and tools to rapidly develop CLI programs. It aims to get rid of boilerplate and aid skiddies.
</p>

## Prerequisites

Skidtools works with Python 3.6 or higher. Support for earlier versions of Python is not provided. Python 2.7 or lower is not supported. 

## Installation

While there are several ways of installing Skidtools, the recommended method is by using `pip` - the Python package manager.

### with pip recommended

Skidtools can be installed with `pip`:

``` sh
pip install skidtools
```

Documentation
-------------
https://docs.clast.dev/skidtools/

License
-------
Abd0s/skidtools is licensed under the [GNU General Public License v3.0](https://github.com/Abd0s/skidtools/blob/master/LICENSE)
